@@ -2,9 +2,9 @@ package Image::CairoSVG;
 use warnings;
 use strict;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
-use Carp qw/carp croak confess cluck/;
+use Carp qw/carp croak/;
 use XML::Parser;
 use Cairo;
 use Image::SVG::Path qw/extract_path_info create_path_string/;
@@ -60,7 +60,7 @@ sub make_cr
 {
     my ($self) = @_;
     if (! $self->{surface}) {
-	confess "BUG: No surface";
+	die "BUG: No surface";
     }
     $self->{cr} = Cairo::Context->create ($self->{surface});
     if (! $self->{cr}) {
@@ -272,12 +272,18 @@ sub circle
     $self->do_svg_attr (%attr);
 }
 
+sub split_points
+{
+    my ($points) = @_;
+    my @points = split /,\s*|\s+/, $points;
+    die "Bad points $points" if @points % 2 != 0;
+    return @points;
+}
+
 sub polygon
 {
     my ($self, %attr) = @_;
-    my $points = $attr{points};
-    my @points = split /,|\s+/, $points;
-    die if @points % 2 != 0;
+    my @points = split_points ($attr{points});
 
     my $cr = $self->{cr};
 
@@ -299,9 +305,7 @@ sub polygon
 sub polyline
 {
     my ($self, %attr) = @_;
-    my $points = $attr{points};
-    my @points = split /,\s+|\s+/, $points;
-    die "Bad points $points" if @points % 2 != 0;
+    my @points = split_points ($attr{points});
 
     my $cr = $self->{cr};
 
@@ -309,14 +313,12 @@ sub polyline
 
     my $y = pop @points;
     my $x = pop @points;
-    print "Moving to $x $y\n";
     $cr->move_to ($x, $y);
 
     while (@points) {
 	$y = pop @points;
 	$x = pop @points;
 	$cr->line_to ($x, $y);
-	print "Line to $x $y\n";
     }
     $self->do_svg_attr (%attr);
 }
